@@ -51,6 +51,20 @@
 /* #define SYS5         1 */
 /* #define SCO_5_STDIO  1 */
 
+/*
+ * Define to 1 if you need to make `inc' set-group-id
+ * because your mail spool is not world writable.  This
+ * will add some extra security checks, although I can't
+ * guarantee it is safe.  Also, you will need to change the
+ * group and add the setgid bit to `inc' manually after
+ * installation.
+ */
+/* #define MAILGROUP  1 */
+
+/*
+ * Turn on locale (setlocale) support
+ */
+#define LOCALE  1
 
 /*
  * Define to 1 the type of file locking to use.  You need to
@@ -64,10 +78,11 @@
 /* #define FLOCK_LOCKING 1 */
 
 /*
- * If you have defined DOT_LOCKING, this will specify
- * the directory where file locks are placed, else the
- * directory of the file to be locked is used.  Don't
- * define this unless you know you need it.
+ * If you have defined DOT_LOCKING, then the default is to
+ * place the lock files in the same directory as the file that
+ * is to be locked.  Alternately, if you define LOCKDIR, you
+ * can specify that all lock files go in a specific directory.
+ * Don't define this unless you know you need it.
  */
 /* #define LOCKDIR "/usr/spool/locks" */
 
@@ -91,11 +106,20 @@
 #define DUMB    1
 
 /*
- * Directs inc/slocal to note "From " lines as Return Path:
- * info.  This is needed if you are using sendmail.
+ * Directs inc/slocal to extract the envelope sender from "From "
+ * line.  If inc/slocal is saving message to folder, then this
+ * sender information is then used to create a Return-Path
+ * header which is then added to the message.
  */
 #define RPATHS  1
 
+/*
+ * If defined, slocal will use `mbox' format when saving to
+ * your standard mail spool.  If not defined, it will use
+ * mmdf format.
+ */
+#define SLOCAL_MBOX  1
+
 /*
  * If this is defined, nmh will recognize the ~ construct.
  */
