@@ -161,15 +161,6 @@ extern char *msg_delim;		/*  .. */
 
 #define OUTPUTLINELEN	72	/* default line length for headers */
 
-/*
- * should be in <stdio.h>
- */
-#if defined(SYS5) || defined(_AIX) || defined(OSF1) || defined(BSD44)
-# define FP FILE*
-#else
-typedef struct _iobuf *FP;
-#endif
-
 /*
  * miscellaneous macros
  */
