@@ -10,7 +10,7 @@
 #include <zotnet/mf/mf.h>
 
 #ifdef BERK
-#include <ctype.h>
+# include <ctype.h>
 #endif /* BERK */
 
 /* High level parsing of addresses:
@@ -83,8 +83,8 @@
 
 
 #if !defined(DUMB) && defined(SENDMTS) && !defined(BANG)
-#define	MF
-#define	UucpChan()	"UUCP"
+# define MF
+# define UucpChan() "UUCP"
 #endif /* MF */
 
 #ifdef BERK
@@ -107,8 +107,8 @@ static char adr[BUFSIZ];
 char *getusr ();
 
 
-char   *getname (addrs)
-register char   *addrs;
+char *
+getname (char *addrs)
 {
 #ifdef	BERK
     /*
