@@ -269,7 +269,8 @@ attr (struct msgs *mp, char *cp)
     if (ssequal ("cur:", cp))	/* this code need to be rewritten... */
 	return OK;
 
-    if (inverted = (dp = m_find (nsequence)) && *dp && ssequal (dp, cp))
+    dp = m_find (nsequence);
+    if ((inverted = (dp && *dp && ssequal (dp, cp))))
 	cp += strlen (dp);
 
     convdir = 1;
