@@ -16,7 +16,7 @@ m_foil (char *path)
     defpath = context = "/dev/null";
 
     if (path) {
-	np = m_defs = (struct node *) malloc (sizeof *np);
+	np = m_defs = (struct node *) malloc (sizeof(*np));
 	if (np == NULL)
 	    adios (NULL, "unable to allocate profile storage");
 
