@@ -237,7 +237,8 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 	     * to a ':', a newline or NAMESZ-1 characters, whichever
 	     * comes first.  
 	     */
-	    cp = name; i = NAMESZ - 1;
+	    cp = name;
+	    i = NAMESZ - 1;
 	    for (;;) {
 		bp = sp = (unsigned char *) iob->_ptr - 1;
 		j = (cnt = iob->_cnt+1) < i ? cnt : i;
@@ -248,8 +249,7 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		if ((cnt -= j) <= 0) {
 		    if (_filbuf(iob) == EOF) {
 			*cp = *buf = 0;
-			advise (NULL, "eof encountered in field \"%s\"",
-				name);
+			advise (NULL, "eof encountered in field \"%s\"", name);
 			return FMTERR;
 		    }
 		} else {
@@ -273,8 +273,7 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		}
 		if ((i -= j) <= 0) {
 		    *cp = *buf = 0;
-		    advise (NULL, "field name \"%s\" exceeds %d bytes",
-			    name, NAMESZ - 1);
+		    advise (NULL, "field name \"%s\" exceeds %d bytes", name, NAMESZ - 1);
 		    state = LENERR;
 		    goto finish;
 		}
@@ -444,7 +443,7 @@ m_unknown(FILE *iob)
  * first call to m_Eom getting executed on each call, i.e., at
  * every newline in the message).
  *
- * If the first line of the maildrop is a Unix "from" line, we
+ * If the first line of the maildrop is a Unix "From " line, we
  * say the style is MBOX and eat the rest of the line.  Otherwise
  * we say the style is MMDF and look for the delimiter string
  * specified when nmh was built (or from the mts.conf file).
@@ -453,7 +452,7 @@ m_unknown(FILE *iob)
     msg_style = MS_UNKNOWN;
 
     pos = ftell (iob);
-    if (fread (text, sizeof *text, 5, iob) == 5
+    if (fread (text, sizeof(*text), 5, iob) == 5
 	    && strncmp (text, "From ", 5) == 0) {
 	msg_style = MS_MBOX;
 	delimstr = "\nFrom ";
@@ -492,10 +491,10 @@ m_unknown(FILE *iob)
      * separator) or the last char (since the matchc would have found it
      * if it was a real delim).
      */
-    pat_map = (unsigned char **) calloc (256, sizeof (unsigned char *));
+    pat_map = (unsigned char **) calloc (256, sizeof(unsigned char *));
 
-    for (cp = (char *)fdelim + 1; cp < (char *)delimend; cp++ )
-	pat_map[*cp] = (unsigned char *)cp;
+    for (cp = (char *) fdelim + 1; cp < (char *) delimend; cp++ )
+	pat_map[*cp] = (unsigned char *) cp;
 
     if (msg_style == MS_MMDF) {
 	/* flush extra msg hdrs */
@@ -574,30 +573,61 @@ m_Eom (int c, FILE *iob)
 
 
 #ifdef RPATHS
-char *
-unixline (void)
-{
-    register char *cp, *dp, *pp;
-    static char unixfrom[BUFSIZ];
+/*
+ * Return the Return-Path and Delivery-Date
+ * header information.
+ *
+ * Currently, I'm assuming that the "From " line
+ * takes one of the following forms.
+ *
+ * From sender date remote from host   (for UUCP delivery)
+ * From sender@host  date              (for sendmail delivery)
+ */
 
-    pp = unixfrom;
-    if ((cp = dp = strchr(unixbuf, ' '))) {
-	while ((cp = strchr(cp + 1, 'r')))
-	    if (strncmp (cp, "remote from ", 12) == 0) {
-		*cp = 0;
-		sprintf (pp, "%s!", cp + 12);
-		pp += strlen (pp);
-		break;
-	    }
-	if (cp == NULL)
-	    cp = unixbuf + strlen (unixbuf);
-	if ((cp -= 25) >= dp)
-	    *cp = 0;
+int
+get_returnpath (char *rp, char *dd)
+{
+    char *ap, *bp, *cp, *dp;
+
+    ap = unixbuf;
+    bp = cp = strchr(ap, ' ');
+
+    /*
+     * Check for "remote from" in envelope to see
+     * if this message uses UUCP style addressing
+     */
+    while ((cp = strchr(++cp, 'r'))) {
+	if (strncmp (cp, "remote from", 11) == 0) {
+	    cp = strrchr (cp, ' ');
+	    break;
+	}
     }
 
-    sprintf (pp, "%s\n", unixbuf);
+    /*
+     * Get the Return-Path information from
+     * the "From " envelope.
+     */
+    if (cp) {
+	/* return path for UUCP style addressing */
+	dp = strchr (++cp, '\n');
+	sprintf (rp, "%.*s!%.*s\n", dp - cp, cp, bp - ap, ap);
+    } else {
+	/* return path for standard domain addressing */
+	sprintf (rp, "%.*s\n", bp - ap, ap);
+    }
+
+    /*
+     * advance over the spaces to get to
+     * delivery date on envelope
+     */
+    while (*bp == ' ')
+	bp++;
+
+    /* Now get delivery date from envelope */
+    sprintf (dd, "%.*s\n", 24, bp);
+
     unixbuf[0] = 0;
-    return unixfrom;
+    return 1;
 }
 #endif /* RPATHS */
 
