@@ -55,7 +55,7 @@ m_readefs (struct node **npp, FILE *ib, char *file, int ctx)
     }
 
     for (state = FLD;;) {
-	switch (state = m_getfld (state, name, field, sizeof field, ib)) {
+	switch (state = m_getfld (state, name, field, sizeof(field), ib)) {
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
@@ -68,8 +68,7 @@ m_readefs (struct node **npp, FILE *ib, char *file, int ctx)
 		if (state == FLDPLUS) {
 		    cp = getcpy (field);
 		    while (state == FLDPLUS) {
-			state = m_getfld
-				    (state, name, field, sizeof field, ib);
+			state = m_getfld (state, name, field, sizeof(field), ib);
 			cp = add (field, cp);
 		    }
 		    np->n_field = trimcpy (cp);
