@@ -52,7 +52,7 @@ main (int argc, char **argv)
     struct smsg *smsgs;
 
 #ifdef LOCALE
-	setlocale(LC_ALL, "");
+    setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
     if ((cp = m_find (invo_name)) != NULL) {
@@ -163,7 +163,8 @@ burst (struct smsg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 {
     int i, j, ld3, wasdlm, mode, msgp;
     register long pos;
-    register char c, cc, *msgnam;
+    register char c, *msgnam;
+    int cc;
     char buffer[BUFSIZ], f1[BUFSIZ], f2[BUFSIZ], f3[BUFSIZ];
     struct stat st;
     register FILE *in, *out;
