@@ -92,13 +92,14 @@ int AssignPriority(char *);
 
 main(int argc, char **argv)
 {
-    char *cp;
-    char **ap;
-    char **argp;
-    char **lastArg;
+    char *cp, **ap;
+    char **argp, **lastArg;
     char *arguments[MAXARGS];
     char buf[100];
 
+#ifdef LOCALE
+    setlocale(LC_ALL, "");
+#endif
     invo_name = r1bindex(argv[0], '/');
     if ((cp = m_find(invo_name)) != NULL) {
 	ap = brkstring(cp = getcpy(cp), " ", "\n");
