@@ -56,7 +56,7 @@ static void forw (char *, char *, int, char **);
 static void rmm (void);
 static void show (int);
 static int eom_action (int);
-static FP mhl_action (char *);
+static FILE *mhl_action (char *);
 static int ask (int);
 #ifdef MIME
 static int nontext (int);
@@ -2492,7 +2492,7 @@ eom_action (int c)
 }
 
 
-static FP
+static FILE *
 mhl_action (char *name)
 {
     int msgnum;
