@@ -12,9 +12,13 @@
 static struct swit switches[] = {
 #define FILESW         0
     { "file name", 0 },
-#define VERSIONSW      1
+#define MBOXSW         1
+    { "mbox", 0 },
+#define MMDFSW         2
+    { "mmdf", 0 },
+#define VERSIONSW      3
     { "version", 0 },
-#define	HELPSW         2
+#define	HELPSW         4
     { "help", 4 },
     { NULL, 0 }
 };
@@ -22,6 +26,8 @@ static struct swit switches[] = {
 extern int errno;
 
 static int md = NOTOK;
+static int mbx_style = MBOX_FORMAT;
+static int mapping = 0;
 
 char *file = NULL;
 
@@ -35,7 +41,7 @@ main (int argc, char **argv)
     struct stat st;
 
 #ifdef LOCALE
-	setlocale(LC_ALL, "");
+    setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
     if ((cp = m_find (invo_name)) != NULL) {
@@ -70,6 +76,15 @@ main (int argc, char **argv)
 		    if (!(file = *argp++) || *file == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
+
+		case MBOXSW:
+		    mbx_style = MBOX_FORMAT;
+		    mapping = 0;
+		    continue;
+		case MMDFSW:
+		    mbx_style = MMDF_FORMAT;
+		    mapping = 1;
+		    continue;
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
@@ -112,7 +127,7 @@ main (int argc, char **argv)
 	    done (1);
     m_setseq (mp);
 
-    if ((md = mbx_open (file, getuid (), getgid (), m_gmprot ())) == NOTOK)
+    if ((md = mbx_open (file, mbx_style, getuid (), getgid (), m_gmprot ())) == NOTOK)
 	adios (file, "unable to open");
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
@@ -122,7 +137,7 @@ main (int argc, char **argv)
 		break;
 	    }
 
-	    if (mbx_copy (file, md, fd, 1, NULL, 1) == NOTOK)
+	    if (mbx_copy (file, mbx_style, md, fd, mapping, NULL, 1) == NOTOK)
 		adios (file, "error writing to file");
 
 	    close (fd);
