@@ -90,7 +90,9 @@ static char cc[] = {
 	0170,0171,0172,0173,0174,0175,0176,0177,
 };
 
-/* DEFINITIONS FOR NEXUS */
+/*
+ * DEFINITIONS FOR NEXUS
+ */
 
 #define	nxtarg()	(*argp ? *argp++ : NULL)
 #define	prvarg()	argp--
@@ -101,36 +103,41 @@ struct nexus {
     int (*n_action)();
 
     union {
-	struct {		/* for {OR,AND,NOT}action */
-	    struct nexus   *un_L_child;
-	    struct nexus   *un_R_child;
-	}       st1;
-#define	n_L_child	un.st1.un_L_child
-#define	n_R_child	un.st1.un_R_child
+	/* for {OR,AND,NOT}action */
+	struct {
+	    struct nexus *un_L_child;
+	    struct nexus *un_R_child;
+	} st1;
 
-	struct {		/* for GREPaction */
-	    int     un_header;
-	    int     un_circf;
-	    char    un_expbuf[ESIZE];
-	    char   *un_patbuf;
-	}       st2;
-#define	n_header	un.st2.un_header
-#define	n_circf		un.st2.un_circf
-#define	n_expbuf	un.st2.un_expbuf
-#define	n_patbuf	un.st2.un_patbuf
+	/* for GREPaction */
+	struct {
+	    int   un_header;
+	    int   un_circf;
+	    char  un_expbuf[ESIZE];
+	    char *un_patbuf;
+	} st2;
 
-	struct {		/* for TWSaction */
-	    char   *un_datef;
-	    int     un_after;
+	/* for TWSaction */
+	struct {
+	    char *un_datef;
+	    int   un_after;
 	    struct tws un_tws;
-	}	st3;
-#define	n_datef		un.st3.un_datef
-#define	n_after		un.st3.un_after
-#define	n_tws		un.st3.un_tws
-
-    }	un;
+	} st3;
+    } un;
 };
 
+#define	n_L_child un.st1.un_L_child
+#define	n_R_child un.st1.un_R_child
+
+#define	n_header un.st2.un_header
+#define	n_circf	 un.st2.un_circf
+#define	n_expbuf un.st2.un_expbuf
+#define	n_patbuf un.st2.un_patbuf
+
+#define	n_datef	 un.st3.un_datef
+#define	n_after	 un.st3.un_after
+#define	n_tws	 un.st3.un_tws
+
 static int talked;
 static int pdebug = 0;
 
@@ -874,15 +881,13 @@ tws_special (char *ap)
 }
 
 
-/* ARGSUSED */
-
-static int  TWSaction (params)
+static int
+TWSaction (params)
 plist
 {
-    int     state;
-    register char  *bp;
-    char    buf[BUFSIZ],
-            name[NAMESZ];
+    int state;
+    register char *bp;
+    char buf[BUFSIZ], name[NAMESZ];
     register struct tws *tw;
 
     fseek (fp, start, 0);
