@@ -16,6 +16,7 @@ extern short ccme;
 extern short format;
 extern short outputlinelen;
 extern short querysw;
+extern int mime;		/* include original as MIME part */
 
 extern char *fcc;
 extern char *filter;
@@ -70,7 +71,7 @@ static void replfilter (FILE *, FILE *);
 
 
 void
-replout (FILE *inb, char *msg, char *drft)
+replout (FILE *inb, char *msg, char *drft, struct msgs *mp)
 {
     register int state;
     register int i;
@@ -230,8 +231,16 @@ finished:
 	fputs ("\nrepl: bad addresses:\n", out);
 	fputs ( badaddrs, out);
     }
-    if (filter)
+    if (filter) {
 	replfilter (inb, out);
+    }
+#ifdef MIME
+    else {
+	if (mime && mp)
+	    fprintf (out, "#forw [original message] +%s %s\n",
+		     mp->foldpath, m_name (mp->lowsel));
+    }
+#endif /* MIME */
 
     if (ferror (out))
 	adios (drft, "error writing");
@@ -255,9 +264,12 @@ static unsigned int bufsiz=0;	/* current size of buf */
 
 #define BUFINCR 512		/* how much to expand buf when if fills */
 
-#define CPY(s) { cp = (s); while (*dst++ = *cp++) ; --dst; }
+#define CPY(s) { cp = (s); while ((*dst++ = *cp++)) ; --dst; }
 
-/* check if there's enough room in buf for str.  add more mem if needed */
+/*
+ * check if there's enough room in buf for str.
+ * add more mem if needed
+ */
 #define CHECKMEM(str) \
 	    if ((len = strlen (str)) >= bufend - dst) {\
 		int i = dst - buf;\
@@ -272,7 +284,8 @@ static unsigned int bufsiz=0;	/* current size of buf */
 	    }
 
 
-/* fmtscan will call this routine if the user includes the function
+/*
+ * fmtscan will call this routine if the user includes the function
  * "(formataddr {component})" in a format string.  "orig" is the
  * original contents of the string register.  "str" is the address
  * string to be formatted and concatenated onto orig.  This routine
@@ -285,13 +298,12 @@ static unsigned int bufsiz=0;	/* current size of buf */
 char *
 formataddr (char *orig, char *str)
 {
-    register int  len;
-    char    baddr[BUFSIZ],
-	    error[BUFSIZ];
-    register int  isgroup;
-    register char  *dst;
-    register char  *cp;
-    register char  *sp;
+    register int len;
+    char baddr[BUFSIZ], error[BUFSIZ];
+    register int isgroup;
+    register char *dst;
+    register char *cp;
+    register char *sp;
     register struct mailname *mp = NULL;
 
     /* if we don't have a buffer yet, get one */
