@@ -47,13 +47,9 @@ static int ncomps = 0;			/* # of interesting components     */
 static char **compbuffers = 0; 		/* buffers for component text      */
 static struct comp **used_buf = 0;	/* stack for comp that use buffers */
 
-char *scanl = 0;			/* text of most recent scanline    */
-
 static int dat[5];			/* aux. data for format routine    */
 
-#ifdef RPATHS
-char *unixline ();			/* info from UNIX From: line       */
-#endif
+char *scanl = 0;			/* text of most recent scanline    */
 
 #define FPUTS(buf) {\
 		if (mh_fputs(buf,scnout) == EOF)\
@@ -82,6 +78,11 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
     char name[NAMESZ];
     static int rlwidth, slwidth;
 
+#ifdef RPATHS
+    char returnpath[BUFSIZ];
+    char deliverydate[BUFSIZ];
+#endif
+
     /* first-time only initialization */
     if (!scanl) {
 	if (width == 0) {
@@ -160,9 +161,15 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	if ((scnout = fopen (scnmsg, "w")) == NULL)
 	    adios (scnmsg, "unable to write");
 #ifdef RPATHS
-	if ((cp = unixline ()) && *cp != '\n') {
+	/*
+	 * Add the Return-Path and Delivery-Date
+	 * header fields to message.
+	 */
+	if (get_returnpath (returnpath, deliverydate)) {
 	    FPUTS ("Return-Path: ");
-	    FPUTS (cp);
+	    FPUTS (returnpath);
+	    FPUTS ("Delivery-Date: ");
+	    FPUTS (deliverydate);
 	}
 #endif /* RPATHS */
     }
