@@ -370,7 +370,7 @@ alert (char *file, int out)
 		if ((in = open (file, 0)) == NOTOK)
 		    admonish (file, "unable to re-open");
 		else {
-		    lseek (out, (off_t) 0, 2);
+		    lseek (out, (off_t) 0, SEEK_END);
 		    strcpy (buf, "\nMessage not delivered to anyone.\n");
 		    write (out, buf, strlen (buf));
 		    strcpy (buf, "\n------- Unsent Draft\n\n");
@@ -382,7 +382,7 @@ alert (char *file, int out)
 		    if (rename (file, strcpy (buf, m_backup (file))) == NOTOK)
 			admonish (buf, "unable to rename %s to", file);
 		}
-	    lseek (out, (off_t) 0, 0);
+	    lseek (out, (off_t) 0, SEEK_SET);
 	    dup2 (out, fileno (stdin));
 	    close (out);
 	    sprintf (buf, "send failed on %s",
@@ -527,7 +527,7 @@ annoaux (int fd)
 	goto oops;
     }
 
-    lseek (fd, (off_t) 0, 0);
+    lseek (fd, (off_t) 0, SEEK_SET);
     if ((fp = fdopen (fd, "r")) == NULL) {
 	if (debugsw)
 	    admonish (NULL, "unable to fdopen annotation list");
