@@ -79,7 +79,7 @@ static char *user = NULL;
 static char *info = NULL;
 static char *file = NULL;
 static char *sender = NULL;
-static char *unixfrom = NULL;
+static char *envelope = NULL;	/* envelope information ("From " line)  */
 static char *mbox = NULL;
 static char *home = NULL;
 
@@ -165,7 +165,7 @@ main (int argc, char **argv)
     char tmpfil[BUFSIZ], **argp = argv + 1;
 
 #ifdef LOCALE
-	setlocale(LC_ALL, "");
+    setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (*argv, '/');
     m_foil (NULL);
@@ -372,10 +372,10 @@ localmail (int fd, char *mdlvr)
 #endif
 
     if (verbose)
-	printf ("(trying normal delivery)\n");
+	printf ("(delivering to standard mail spool)\n");
 
-    /* delivery to standard mail spool */
-#ifdef RPATHS
+    /* deliver to standard mail spool */
+#ifdef SLOCAL_MBOX
     return usr_file (fd, mbox, MBOX_FORMAT);
 #else
     return usr_file (fd, mbox, MMDF_FORMAT);
@@ -1027,8 +1027,8 @@ alrmser (int i)
 
 
 /*
- * Get the `sender' info from the
- * "From " line.
+ * Get the `sender' from the envelope
+ * information ("From " line).
  */
 
 static void
@@ -1038,9 +1038,12 @@ copyinfo (FILE *fp, char *from)
     register char *cp;
     static char buffer[BUFSIZ];
 
-    /* copy of the "From " line from copyfile */
-    if (unixfrom)
-	strcpy (from, unixfrom);
+    /*
+     * copy of the envelope information
+     * ("From " line) from copyfile
+     */
+    if (envelope)
+	strcpy (from, envelope);
     else if (fgets (from, BUFSIZ, fp) == NULL)
 	adios (NULL, "no message");
 
@@ -1080,7 +1083,7 @@ copyinfo (FILE *fp, char *from)
 static int
 copyfile (int qd, char *tmpfil, int fold)
 {
-    register int i, first = 0, fd1, fd2;
+    register int i, first = 1, fd1, fd2;
     char buffer[BUFSIZ];
     register FILE *qfp, *ffp;
 
@@ -1138,50 +1141,56 @@ you_lose: ;
      */
     i = strlen ("From ");
     while (fgets (buffer, sizeof(buffer), qfp)) {
-	if (!strncmp (buffer, "From ", i)) {
-	    if (first == 0) {
+	if (first) {
+	    first = 0;
+	    if (!strncmp (buffer, "From ", i)) {
 #ifdef RPATHS
 		char *fp, *cp, *hp, *ep;
 #endif
 		/* save "From " line for later */
-		unixfrom = getcpy (buffer);
-#ifdef RPATHS
+		envelope = getcpy (buffer);
+
+#if 0
 		/* First go ahead and put "From " line in message */
 		fputs (buffer, ffp);
 		if (ferror (ffp))
 		    goto fputs_error;
 #endif
 
-		/* Now put the delivery date in message */
-		fputs (ddate, ffp);
-		if (ferror (ffp))
-		    goto fputs_error;
-
 #ifdef RPATHS
 		/*
-		 * Now create a "Return-Path:" line from
-		 * the "From " line and add it.
+		 * Now create a "Return-Path:" line
+		 * from the "From " line.
 		 */
-		hp = cp = strchr(fp = unixfrom + i, ' ');
+		hp = cp = strchr(fp = envelope + i, ' ');
 		while ((hp = strchr(++hp, 'r')))
 		    if (uprf (hp, "remote from")) {
 			hp = strrchr(hp, ' ');
 			break;
 		    }
 		if (hp) {
-		    ep = strrchr(++hp, '\n');
+		    /* return path for UUCP style addressing */
+		    ep = strchr(++hp, '\n');
 		    sprintf (buffer, "Return-Path: %.*s!%.*s\n", ep - hp, hp, cp - fp, fp);
 		} else {
+		    /* return path for standard domain addressing */
 		    sprintf (buffer, "Return-Path: %.*s\n", cp - fp, fp);
 		}
-#else
-		/* but don't put it in the file */
-		continue;
+
+		/* Add Return-Path header to message */
+		fputs (buffer, ffp);
+		if (ferror (ffp))
+		    goto fputs_error;
 #endif
+		/* Put the delivery date in message */
+		fputs (ddate, ffp);
+		if (ferror (ffp))
+		    goto fputs_error;
+
+		continue;
 	    }
 	}
 
-	first++;
 	fputs (buffer, ffp);
 	if (ferror (ffp))
 	    goto fputs_error;
