@@ -5,8 +5,8 @@
  * $Id$
  */
 
+/* DST vs. GMT nonsense */
 #define	DSTXXX
-			/* DST vs. GMT nonsense */
 
 struct tws {
     int tw_sec;
@@ -34,15 +34,11 @@ struct tws {
 #define	TW_ZONE	 0x0020	/* use numeric timezones only     */
 
 #ifdef ATZ
-  /*
-   * use alpha-numeric timezones
-   */
-# define dtime(cl) dasctime (dlocaltime (cl), TW_NULL)
+  /* use alpha-numeric timezones */
+# define dtime(t) dasctime (dlocaltime (t), TW_NULL)
 #else
-  /*
-   * use numeric timezones
-   */
-# define dtime(cl) dasctime (dlocaltime (cl), TW_ZONE)
+  /* use numeric timezones */
+# define dtime(t) dasctime (dlocaltime (t), TW_ZONE)
 #endif
 
 #define	dtwszone(tw) dtimezone (tw->tw_zone, tw->tw_flags)
